/******************************************************************************
*
* official project name:  CPoker 92Plus
* project language:       TI-GCC / English
* author:                 Greg S. <inittab@unixdev.net>
* file title:             CDrawing.c
* initial file date:      ** unknown **
* file purpose:           graphics routines
*
*******************************************************************************/
#include "CAllDef.h"

static unsigned char heart[]={0x00, 0x00, 0x14, 0x3e, 0x3e, 0x1c, 0x08};
static unsigned char diamond[]={0x00, 0x00, 0x08, 0x1c, 0x3e, 0x1c, 0x08};
static unsigned char spade[]={0x00, 0x00, 0x08, 0x1c, 0x3e, 0x3e, 0x08};
static unsigned char club[]={0x00, 0x1c, 0x1c, 0x7f, 0x7f, 0x7f, 0x08};

void PxlVert(int col) {
  DrawLine(col, 0, col, 127, A_NORMAL);
}

void PxlHorz(int row) {
  DrawLine(0, row, 239, row, A_NORMAL);
}

void DrawBox(int x, int y, int x2, int y2, int mode) {
  DrawLine(x, y, x2, y, mode);
  DrawLine(x2, y, x2, y2, mode);
  DrawLine(x2, y2, x, y2, mode);
  DrawLine(x, y2, x, y, mode);
}

void DrawFullScreen(unsigned long mon, unsigned long wag) {
  ClearScreen();
  //Double-Thick Lines
  PxlVert(0);   PxlVert(1); //left
  PxlVert(175); PxlVert(176); //middle
  PxlVert(238); PxlVert(239); //right
  PxlHorz(0);   PxlHorz(1); //top
  PxlHorz(120); PxlHorz(121); //Bottom line
  //Top StatusBar
  DrawBox(3, 50, 173, 60, A_NORMAL);
  DrawBox(37, 50, 71, 60, A_NORMAL);
  DrawBox(105, 50, 139, 60, A_NORMAL);
  DrawStr(17, 52, "1", A_REPLACE);
  DrawStr(51, 52, "2", A_REPLACE);
  DrawStr(85, 52, "3", A_REPLACE);
  DrawStr(119, 52, "4", A_REPLACE);
  DrawStr(153, 52, "5", A_REPLACE);
  DrawStr(5, 104, "Tap [ENTER] to stay...", A_REPLACE);
  //Bottom StatusBar
  DrawBox(3, 102, 173, 112, A_NORMAL);
  //Title Box
  DrawBox(190, 15, 224, 34, A_NORMAL);
  DrawStr(192, 17, "POKER", A_REPLACE);
  DrawLine(192, 25, 222, 25, A_NORMAL); //Seperator
  Sprite8(214, 26, 7, heart, LCD_MEM, SPRT_XOR);
  Sprite8(198, 26, 7, diamond, LCD_MEM, SPRT_XOR);
  Sprite8(191, 26, 7, spade, LCD_MEM, SPRT_XOR);
  Sprite8(206, 26, 7, club, LCD_MEM, SPRT_XOR);
  DrawLine(191, 35, 225, 35, A_NORMAL); //Shadow Bottom
  DrawLine(225, 16, 225, 35, A_NORMAL); // ...   Right
  //Stats
  DrawStr(177, 40, "Gross:", A_REPLACE); printf_xy(183, 49, "$%lu", mon);
  DrawStr(177, 58, "Wager:", A_REPLACE); printf_xy(183, 67, "$%lu", wag);
  //NameLogo
  DrawLine(177, 102, 225, 102, A_NORMAL);
  DrawLine(225, 102, 225, 110, A_NORMAL);
  DrawLine(225, 110, 237, 110, A_NORMAL);
  DrawLine(177, 112, 212, 112, A_NORMAL);
  DrawLine(212, 112, 212, 119, A_NORMAL);
  DrawStr(177, 104, "Schenzel", A_REPLACE);
  DrawStr(213, 112, "Soft", A_REPLACE);
}

void dispSuite(int who, int what) {
  int y=0;
  char *msg="", *person="";
  if (who==1) {
    y=52;
    person="You have";
  }
  else if (who==2) {
    y=104;
    person="Dealer has";
  }
  switch (what) {
  case PK_NOTHING: msg="Nothing"; break;
  case PK_ONEPAIR: msg="One Pair"; break;
  case PK_TWOPAIRS: msg="Two Pairs"; break;
  case PK_THREEOFAKIND: msg="Three of a Kind"; break;
  case PK_STRAIGHT: msg="A Straight"; break;
  case PK_FLUSH: msg="A Flush"; break;
  case PK_FULLHOUSE: msg="A Full House"; break;
  case PK_FOUROFAKIND: msg="Four of a Kind"; break;
  case PK_STRAIGHTFLUSH: msg="A Straight Flush"; break; //dealer may be too long
  case PK_ROYALFLUSH: msg="A Royal Flush"; break;
  }
  printf_xy(5, y, "%s: %s", person, msg);
}

void DrawCard(int num, int pic, int ltor, int topbot) {
  int cleft=0, nleft=0, pleft=0, ctop=0, ntop=0, ptop=0;
  //determine coordinates of left/right cards
  if (ltor==1) {
   cleft=4; nleft=7; pleft=24;
  }
  else if (ltor==2) {
   cleft=38; nleft=41; pleft=58;
  }
  else if (ltor==3) {
   cleft=72; nleft=75; pleft=92;
  }
  else if (ltor==4) {
   cleft=106; nleft=109; pleft=126;
  }
  else if (ltor==5) {
   cleft=140; nleft=143; pleft=160;
  }
  //determine coordinates of top/bottom cards
  if (topbot==1) {
   ctop=10; ntop=14; ptop=36;
  }
  else if (topbot==2) {
   ctop=62; ntop=66; ptop=88;
  }
  //label cards
  if (num>1 && num<11) printf_xy(nleft, ntop, "%i", num);
  if (num==1) printf_xy(nleft, ntop, "A");
  if (num==11) printf_xy(nleft, ntop, "J");
  if (num==12) printf_xy(nleft, ntop, "Q");
  if (num==13) printf_xy(nleft, ntop, "K");
  if (pic==1) Sprite8(pleft, ptop, 7, heart, LCD_MEM, SPRT_XOR);
  if (pic==2) Sprite8(pleft, ptop, 7, diamond, LCD_MEM, SPRT_XOR);
  if (pic==3) Sprite8(pleft, ptop, 7, spade, LCD_MEM, SPRT_XOR);
  if (pic==4) Sprite8(pleft, ptop, 7, club, LCD_MEM, SPRT_XOR);
  DrawBox(cleft, ctop, cleft+32, ctop+38, A_NORMAL);
  DrawLine(cleft+32, ctop, cleft, ctop+38, A_NORMAL);
}

void shadeSelNum(int ltor) {
  int cleft=0, i=0;
  if (ltor==1) cleft=4;
  if (ltor==2) cleft=38;
  if (ltor==3) cleft=72;
  if (ltor==4) cleft=106;
  if (ltor==5) cleft=140;
  for (i=51; i<=59; i++) DrawLine(cleft, i, cleft+32, i, A_XOR);
}

void ClearCard(int num) { //+1 check
  if (num==1) {
   DrawStr(7, 14, "  ", A_REPLACE);
   DrawStr(24, 36, "  ", A_REPLACE);
  }
  else if (num==2) {
   DrawStr(41, 14, "  ", A_REPLACE);
   DrawStr(58, 36, "  ", A_REPLACE);
  }
  else if (num==3) {
   DrawStr(75, 14, "  ", A_REPLACE);
   DrawStr(92, 36, "  ", A_REPLACE);
  }
  else if (num==4) {
   DrawStr(109, 14, "  ", A_REPLACE);
   DrawStr(126, 36, "  ", A_REPLACE);
  }
  else if (num==5) {
   DrawStr(143, 14, "  ", A_REPLACE);
   DrawStr(160, 36, "  ", A_REPLACE);
  }
}
