/******************************************************************************
*
* official project name:  CPoker 92Plus
* project language:       TI-GCC / English
* author:                 Greg S. <inittab@unixdev.net>
* file title:             CKeyboard.c
* initial file date:      ** unknown **
* file purpose:           keyboard handling routines (low-level)
*
*******************************************************************************/
#include "CAllDef.h"
/*===============================
Keyboard Matrix on the TI-92 Plus
=================================
-------------------------------------------------------------------------------
 ---- |     128|      64|      32|      16|       8|       4|        2|       1
------|--------|--------|--------|--------|--------|--------|---------|--------
0xFFFE| down   | right  | up     | left   | hand   | shift  | diamond | 2nd
0xFFFD| 3      | 2      | 1      | F8     | W      | S      | Z       | ------
0xFFFB| 6      | 5      | 4      | F3     | E      | D      | X       | ------
0xFFF7| 9      | 8      | 7      | F7     | R      | F      | C       | STO
0xFFEF| ,      | )      | (      | F2     | T      | G      | V       | space
0xFFDF| TAN    | COS    | SIN    | F6     | Y      | H      | B       | /
0xFFBF| P      | ENTER2 | LN     | F1     | U      | J      | N       | ^
0xFF7F| *      | APPS   | CLEAR  | F5     | I      | K      | M       | =
0xFEFF| ------ | ESC    | MODE   | +      | O      | L      | theta   | backspc
0xFDFF| (-)    | .      | 0      | F4     | Q      | A      | ENTER1  | -
-------------------------------------------------------------------------------
NOTES:  ENTER1 is on the alphabetic and numeric keypads.
        ENTER2 is next to the cursor pad.
        Little of this applies to a TI-89.
     This is the simplest explanation of _rowread & the keyboard matrix you
will find. _rowread() checks to see if a key is CURRENTLY being held down. It
is the lowest-level routine of its nature, and has many benefits, including:
speed, no StatusBar/Interupts (for undisturbed graphics), and just more overall
control. To build a test using _rowread(), find the key that you want to test
in the above table. Then build your test like this: "if
(_rowread(leftMostItemInRow) & topMostItemInColumn)". So the following would
be a legal way to check whether or not ESC was pressed:
 if (_rowread(0xFEFF) & 64) {
  //do something with ESC key
 }*/
//NOTE: Uncomment the last OSSetSR to re-enable interrupts after method execution.
unsigned short waitKey(char *disp) {
  unsigned char FEFF, FDFF, FFFD, FFFB, FFF7, FF7F, FFBF;
  unsigned short i;
  unsigned int k;

  if (disp != "") {
    ST_helpMsg(disp);
    PxlHorz(121);
  }
  ST_busy(ST_IDLE);

  OSSetSR(0x0700); //disable ALL interupts (implemented for status line)
  do {
    FDFF = _rowread(0xFDFF);
    FEFF = _rowread(0xFEFF);
    FF7F = _rowread(0xFF7F);
    FFBF = _rowread(0xFFBF);
    FFF7 = _rowread(0xFFF7);    
    FFFB = _rowread(0xFFFB);    
    FFFD = _rowread(0xFFFD);
    if (FEFF & 16) { //+
      OSContrastUp();
      WaitForMillis(150);
    }
    else if (FDFF & 1) { //-
      OSContrastDn();
      WaitForMillis(150);
    }
    else if (FEFF & 1) { //backspace
      i = keyBack;
      goto complete;
    }
    else if (FEFF & 64) { // check for escape
      i = keyEsc;
      goto complete;
    }
    else if (FDFF & 32) { //0
      i = keyNum0;
      goto complete;
    }
    else if (FFFD & 32) { //1
      i = keyNum1;
      goto complete;
    }
    else if (FFFD & 64) { //2
      i = keyNum2;
      goto complete;
    }
    else if (FFFD & 128) { //3
      i = keyNum3;
      goto complete;
    }
    else if (FFFB & 32) { //4
      i = keyNum4;
      goto complete;
    }
    else if (FFFB & 64) { //5
      i = keyNum5;
      goto complete;
    }
    else if (FFFB & 128) { //6
      i = keyNum6;
      goto complete;
    }
    else if (FFF7 & 32) { //7
      i = keyNum7;
      goto complete;
    }
    else if (FFF7 & 64) { //8
      i = keyNum8;
      goto complete;
    }
    else if (FFF7 & 128) { //9
      i = keyNum9;
      goto complete;
    }
    else if (FF7F & 32) { // check for clear
      i = keyClear;
      goto complete;
    }
    else if (FDFF & 2 ||
             FFBF & 64) { // check for enter
      i = keyEnter;
      goto complete;
    }
  } while (1);

complete:
//  OSSetSR(0x0000);
  waitForKeyUp();
  return i;
}

void pause(void) {
  char *msg;
  msg = "Press [ENTER] to continue...";
doAgain:
  if (waitKey(msg) == keyEnter) return;
  msg = "";
  goto doAgain;
}

void waitForKeyUp(void) {
  while (_rowread(0x0000) & 255); //Wait until key comes up...
}
